pub struct CooldownSetSpellEntry {
pub spell_id: i32,
pub category: i32,
pub player_condition_id: i32,
pub order_index: i32,
pub flags: i32,
}Expand description
Flat cooldown set spell entry (stored as jsonb within CooldownSetFlat).
Fields
spell_id: i32category: i32player_condition_id: i32order_index: i32flags: i32Trait Implementations
Sourceimpl Clone for CooldownSetSpellEntry
impl Clone for CooldownSetSpellEntry
Sourcefn clone(&self) -> CooldownSetSpellEntry
fn clone(&self) -> CooldownSetSpellEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CooldownSetSpellEntry
impl Debug for CooldownSetSpellEntry
Sourceimpl Default for CooldownSetSpellEntry
impl Default for CooldownSetSpellEntry
Sourcefn default() -> CooldownSetSpellEntry
fn default() -> CooldownSetSpellEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CooldownSetSpellEntry
impl<'de> Deserialize<'de> for CooldownSetSpellEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CooldownSetSpellEntry
impl JsonSchema for CooldownSetSpellEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CooldownSetSpellEntry
impl RefUnwindSafe for CooldownSetSpellEntry
impl Send for CooldownSetSpellEntry
impl Sync for CooldownSetSpellEntry
impl Unpin for CooldownSetSpellEntry
impl UnsafeUnpin for CooldownSetSpellEntry
impl UnwindSafe for CooldownSetSpellEntry