pub struct CurvePointFlat {
pub id: i32,
pub curve_id: i32,
pub order_index: i32,
pub pos_0: f64,
pub pos_1: f64,
pub pos_pre_squish_0: f64,
pub pos_pre_squish_1: f64,
}Fields
id: i32curve_id: i32order_index: i32pos_0: f64pos_1: f64pos_pre_squish_0: f64pos_pre_squish_1: f64Trait Implementations
Sourceimpl Clone for CurvePointFlat
impl Clone for CurvePointFlat
Sourcefn clone(&self) -> CurvePointFlat
fn clone(&self) -> CurvePointFlat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CopyInsert for CurvePointFlat
impl CopyInsert for CurvePointFlat
Sourceimpl Debug for CurvePointFlat
impl Debug for CurvePointFlat
Sourceimpl Default for CurvePointFlat
impl Default for CurvePointFlat
Sourcefn default() -> CurvePointFlat
fn default() -> CurvePointFlat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CurvePointFlat
impl<'de> Deserialize<'de> for CurvePointFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CurvePointFlat> for JsValuewhere
CurvePointFlat: Serialize,
impl From<CurvePointFlat> for JsValuewhere
CurvePointFlat: Serialize,
Sourcefn from(value: CurvePointFlat) -> Self
fn from(value: CurvePointFlat) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
impl FromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &CurvePointFlatwhere
CurvePointFlat: Serialize,
impl IntoWasmAbi for &CurvePointFlatwhere
CurvePointFlat: Serialize,
Sourceimpl IntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
impl IntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
Sourceimpl JsonSchema for CurvePointFlat
impl JsonSchema for CurvePointFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
impl OptionIntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
Sourceimpl RefFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<CurvePointFlat>
type Anchor = SelfOwner<CurvePointFlat>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for CurvePointFlat
impl Serialize for CurvePointFlat
Sourceimpl Tsify for CurvePointFlat
impl Tsify for CurvePointFlat
const DECL: &'static str = "export interface CurvePointFlat {\n id: number;\n curve_id: number;\n order_index: number;\n pos_0: number;\n pos_1: number;\n pos_pre_squish_0: number;\n pos_pre_squish_1: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for CurvePointFlatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
impl VectorIntoWasmAbi for CurvePointFlatwhere
CurvePointFlat: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for CurvePointFlat
impl WasmDescribe for CurvePointFlat