pub struct GemPropertiesFlat {
pub id: i32,
pub enchant_id: i32,
pub gem_type: i32,
}Fields
id: i32enchant_id: i32gem_type: i32Trait Implementations
Sourceimpl Clone for GemPropertiesFlat
impl Clone for GemPropertiesFlat
Sourcefn clone(&self) -> GemPropertiesFlat
fn clone(&self) -> GemPropertiesFlat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CopyInsert for GemPropertiesFlat
impl CopyInsert for GemPropertiesFlat
Sourceimpl Debug for GemPropertiesFlat
impl Debug for GemPropertiesFlat
Sourceimpl Default for GemPropertiesFlat
impl Default for GemPropertiesFlat
Sourcefn default() -> GemPropertiesFlat
fn default() -> GemPropertiesFlat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GemPropertiesFlat
impl<'de> Deserialize<'de> for GemPropertiesFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GemPropertiesFlat> for JsValuewhere
GemPropertiesFlat: Serialize,
impl From<GemPropertiesFlat> for JsValuewhere
GemPropertiesFlat: Serialize,
Sourcefn from(value: GemPropertiesFlat) -> Self
fn from(value: GemPropertiesFlat) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
impl FromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
impl IntoWasmAbi for &GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
Sourceimpl IntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
impl IntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
Sourceimpl JsonSchema for GemPropertiesFlat
impl JsonSchema for GemPropertiesFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
impl OptionIntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
Sourceimpl RefFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<GemPropertiesFlat>
type Anchor = SelfOwner<GemPropertiesFlat>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for GemPropertiesFlat
impl Serialize for GemPropertiesFlat
Sourceimpl Tsify for GemPropertiesFlat
impl Tsify for GemPropertiesFlat
const DECL: &'static str = "export interface GemPropertiesFlat {\n id: number;\n enchant_id: number;\n type: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for GemPropertiesFlatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
impl VectorIntoWasmAbi for GemPropertiesFlatwhere
GemPropertiesFlat: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for GemPropertiesFlat
impl WasmDescribe for GemPropertiesFlat