pub struct PowerTypeFlat {Show 13 fields
pub id: i32,
pub name_global_string_tag: String,
pub cost_global_string_tag: String,
pub power_type_enum: i32,
pub min_power: i32,
pub max_base_power: i32,
pub center_power: i32,
pub default_power: i32,
pub display_modifier: f32,
pub regen_interrupt_time_ms: i32,
pub regen_peace: f32,
pub regen_combat: f32,
pub flags: i32,
}Fields
id: i32name_global_string_tag: Stringcost_global_string_tag: Stringpower_type_enum: i32min_power: i32max_base_power: i32center_power: i32default_power: i32display_modifier: f32regen_interrupt_time_ms: i32regen_peace: f32regen_combat: f32flags: i32Trait Implementations
Sourceimpl Clone for PowerTypeFlat
impl Clone for PowerTypeFlat
Sourcefn clone(&self) -> PowerTypeFlat
fn clone(&self) -> PowerTypeFlat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CopyInsert for PowerTypeFlat
impl CopyInsert for PowerTypeFlat
Sourceimpl Debug for PowerTypeFlat
impl Debug for PowerTypeFlat
Sourceimpl Default for PowerTypeFlat
impl Default for PowerTypeFlat
Sourcefn default() -> PowerTypeFlat
fn default() -> PowerTypeFlat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PowerTypeFlat
impl<'de> Deserialize<'de> for PowerTypeFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PowerTypeFlat
impl JsonSchema for PowerTypeFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PowerTypeFlat
impl RefUnwindSafe for PowerTypeFlat
impl Send for PowerTypeFlat
impl Sync for PowerTypeFlat
impl Unpin for PowerTypeFlat
impl UnsafeUnpin for PowerTypeFlat
impl UnwindSafe for PowerTypeFlat